@@ -34,17 +34,17 @@
 #include <gnome.h>
 #include <gtk/gtksignal.h>
 #include <libgnorba/gnorba.h>
-#include <libnautilus-extensions/nautilus-background.h>
-#include <libnautilus-extensions/nautilus-directory-background.h>
-#include <libnautilus-extensions/nautilus-file-utilities.h>
-#include <libnautilus-extensions/nautilus-file.h>
-#include <libnautilus-extensions/nautilus-glib-extensions.h>
-#include <libnautilus-extensions/nautilus-gtk-extensions.h>
-#include <libnautilus-extensions/nautilus-gtk-macros.h>
-#include <libnautilus-extensions/nautilus-image.h>
-#include <libnautilus-extensions/nautilus-label.h>
-#include <libnautilus-extensions/nautilus-metadata.h>
-#include <libnautilus-extensions/nautilus-string.h>
+#include <eel/eel-background.h>
+#include <libnautilus-private/nautilus-directory-background.h>
+#include <libnautilus-private/nautilus-file-utilities.h>
+#include <libnautilus-private/nautilus-file.h>
+#include <eel/eel-glib-extensions.h>
+#include <eel/eel-gtk-extensions.h>
+#include <eel/eel-gtk-macros.h>
+#include <eel/eel-image.h>
+#include <eel/eel-label.h>
+#include <libnautilus-private/nautilus-metadata.h>
+#include <eel/eel-string.h>
 #include <libnautilus/libnautilus.h>
 #include <limits.h>
 #include <sys/stat.h>
@@ -77,7 +77,7 @@ static void hardware_view_load_location_callback      (NautilusView
                                                        const char                *location,
                                                        NautilusHardwareView      *hardware_view);
 
-NAUTILUS_DEFINE_CLASS_BOILERPLATE (NautilusHardwareView, nautilus_hardware_view, GTK_TYPE_EVENT_BOX)
+EEL_DEFINE_CLASS_BOILERPLATE (NautilusHardwareView, nautilus_hardware_view, GTK_TYPE_EVENT_BOX)
 
 #define HARDWARE_DEFAULT_BACKGROUND_COLOR  "rgb:DDDD/DDDD/BBBB"
 
@@ -99,7 +99,7 @@ nautilus_hardware_view_initialize_class (NautilusHardwareViewClass *klass)
 static void
 nautilus_hardware_view_initialize (NautilusHardwareView *hardware_view)
 {
-  	NautilusBackground *background;
+  	EelBackground *background;
 	hardware_view->details = g_new0 (NautilusHardwareViewDetails, 1);
 
 	hardware_view->details->nautilus_view = nautilus_view_new (GTK_WIDGET (hardware_view));
@@ -111,13 +111,13 @@ nautilus_hardware_view_initialize (NautilusHardwareView *hardware_view)
 
 	hardware_view->details->form = NULL;
 
-  	background = nautilus_get_widget_background (GTK_WIDGET (hardware_view));
-  	nautilus_background_set_color (background, HARDWARE_DEFAULT_BACKGROUND_COLOR);
+  	background = eel_get_widget_background (GTK_WIDGET (hardware_view));
+  	eel_background_set_color (background, HARDWARE_DEFAULT_BACKGROUND_COLOR);
 
 	/* prepare ourselves to receive dropped objects */
 	gtk_drag_dest_set (GTK_WIDGET (hardware_view),
 			   GTK_DEST_DEFAULT_MOTION | GTK_DEST_DEFAULT_HIGHLIGHT | GTK_DEST_DEFAULT_DROP, 
-			   hardware_dnd_target_table, NAUTILUS_N_ELEMENTS (hardware_dnd_target_table), GDK_ACTION_COPY);
+			   hardware_dnd_target_table, EEL_N_ELEMENTS (hardware_dnd_target_table), GDK_ACTION_COPY);
   		
 	gtk_widget_show_all (GTK_WIDGET (hardware_view));
 }
@@ -131,7 +131,7 @@ nautilus_hardware_view_destroy (GtkObject *object)
 
 	g_free (hardware_view->details);
 
-	NAUTILUS_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 /* Component embedding support */
@@ -180,7 +180,7 @@ extract_info (char* data, const char *field_name, int nth)
 		if (info_array[index] == NULL) {
 			break;
                 }
-		if (nautilus_str_has_prefix(info_array[index], field_name)) {
+		if (eel_str_has_prefix(info_array[index], field_name)) {
 			if (nth > 0) {
                                 nth--;
 			} else {
@@ -358,15 +358,15 @@ setup_form_title (NautilusHardwareView *view,
 	if (image_name != NULL) {
  		file_name = gnome_pixmap_file (image_name);
 		if (file_name != NULL) {
-			temp_widget = nautilus_image_new (file_name);
+			temp_widget = eel_image_new (file_name);
 			gtk_box_pack_start (GTK_BOX(temp_container), temp_widget, 0, 0, 8);		
 			gtk_widget_show (temp_widget);
 			g_free (file_name);
 		}
 	}
 	
- 	temp_widget = nautilus_label_new (title_text);
-	nautilus_label_make_larger (NAUTILUS_LABEL (temp_widget), 10);
+ 	temp_widget = eel_label_new (title_text);
+	eel_label_make_larger (EEL_LABEL (temp_widget), 10);
 
 	gtk_box_pack_start (GTK_BOX (temp_container), temp_widget, 0, 0, 8);			 	
 	gtk_widget_show (temp_widget);
@@ -419,13 +419,13 @@ setup_overview_form (NautilusHardwareView *view)
 		gtk_widget_show (temp_box);
 
 		file_name = nautilus_pixmap_file ("cpu.png");
-                temp_widget = nautilus_image_new (file_name);
+                temp_widget = eel_image_new (file_name);
 		gtk_box_pack_start (GTK_BOX(temp_box), temp_widget, 0, 0, 0);		
 		gtk_widget_show (temp_widget);
 		g_free (file_name);
 		
-		temp_widget = nautilus_label_new (temp_text);
-		nautilus_label_make_larger (NAUTILUS_LABEL (temp_widget), 2);
+		temp_widget = eel_label_new (temp_text);
+		eel_label_make_larger (EEL_LABEL (temp_widget), 2);
 		g_free(temp_text);
 		gtk_box_pack_start(GTK_BOX(temp_box), temp_widget, 0, 0, 0 );			
 		gtk_widget_show (temp_widget);
@@ -439,14 +439,14 @@ setup_overview_form (NautilusHardwareView *view)
 	gtk_widget_show (temp_box);
 
  	file_name = nautilus_pixmap_file ("memory_chip.gif");
-  	temp_widget = nautilus_image_new (file_name);
+  	temp_widget = eel_image_new (file_name);
 	gtk_box_pack_start(GTK_BOX(temp_box), temp_widget, 0, 0, 0);		
   	gtk_widget_show(temp_widget);
   	g_free (file_name);
 	
 	temp_text = get_RAM_description ();
-	temp_widget = nautilus_label_new (temp_text);
-	nautilus_label_make_larger (NAUTILUS_LABEL (temp_widget), 2);
+	temp_widget = eel_label_new (temp_text);
+	eel_label_make_larger (EEL_LABEL (temp_widget), 2);
 	g_free (temp_text);
 	gtk_box_pack_start (GTK_BOX(temp_box), temp_widget, 0, 0, 0 );			
  	gtk_widget_show (temp_widget);
@@ -477,16 +477,16 @@ setup_overview_form (NautilusHardwareView *view)
                                         file_name = nautilus_pixmap_file("i-harddisk.png");
                                 }
                                 
-				pixmap_widget = nautilus_image_new (file_name);
+				pixmap_widget = eel_image_new (file_name);
 				gtk_box_pack_start (GTK_BOX(temp_box), pixmap_widget, 0, 0, 0);
 				gtk_widget_show(pixmap_widget);
 				g_free(file_name);
 				g_free(ide_media);
                                 
 				temp_text = get_IDE_description (device);
-				temp_widget = nautilus_label_new (temp_text);
-				nautilus_label_make_larger (NAUTILUS_LABEL (temp_widget), 2);
-				nautilus_label_set_justify (NAUTILUS_LABEL (temp_widget), GTK_JUSTIFY_CENTER);
+				temp_widget = eel_label_new (temp_text);
+				eel_label_make_larger (EEL_LABEL (temp_widget), 2);
+				eel_label_set_justify (EEL_LABEL (temp_widget), GTK_JUSTIFY_CENTER);
 
 				g_free(temp_text);
                                 gtk_box_pack_start(GTK_BOX(temp_box), temp_widget, 0, 0, 0);
@@ -504,7 +504,7 @@ setup_overview_form (NautilusHardwareView *view)
 /* set up the widgetry for the CPU page */
 
 static void
-setup_CPU_form(NautilusHardwareView *view)
+setup_CPU_form (NautilusHardwareView *view)
 {
 	char *message;
 	GtkWidget *temp_widget;
@@ -517,10 +517,10 @@ setup_CPU_form(NautilusHardwareView *view)
 	/* set up the title */	
 	setup_form_title (view, NULL, "CPU");
 	
-	message = "This is a placeholder for the CPU page.";
-	temp_widget = nautilus_label_new (message);
-	nautilus_label_make_larger (NAUTILUS_LABEL (temp_widget), 2);
- 	nautilus_label_set_wrap(NAUTILUS_LABEL(temp_widget), TRUE);
+	message = _("This is a placeholder for the CPU page.");
+	temp_widget = eel_label_new (message);
+	eel_label_make_larger (EEL_LABEL (temp_widget), 2);
+ 	eel_label_set_wrap(EEL_LABEL(temp_widget), TRUE);
 	
 	gtk_box_pack_start(GTK_BOX(view->details->form), temp_widget, 0, 0, 12);			
  	gtk_widget_show (temp_widget);
@@ -529,7 +529,7 @@ setup_CPU_form(NautilusHardwareView *view)
 /* set up the widgetry for the RAM page */
 
 static void
-setup_RAM_form(NautilusHardwareView *view)
+setup_RAM_form (NautilusHardwareView *view)
 {
 	char *message;
 	GtkWidget *temp_widget;
@@ -542,10 +542,10 @@ setup_RAM_form(NautilusHardwareView *view)
 	/* set up the title */	
 	setup_form_title (view, NULL, "RAM");
 	
-	message = "This is a placeholder for the RAM page.";
-	temp_widget = nautilus_label_new (message);
-	nautilus_label_make_larger (NAUTILUS_LABEL (temp_widget), 2);
- 	nautilus_label_set_wrap(NAUTILUS_LABEL(temp_widget), TRUE);
+	message = _("This is a placeholder for the RAM page.");
+	temp_widget = eel_label_new (message);
+	eel_label_make_larger (EEL_LABEL (temp_widget), 2);
+ 	eel_label_set_wrap(EEL_LABEL(temp_widget), TRUE);
 	
 	gtk_box_pack_start(GTK_BOX(view->details->form), temp_widget, 0, 0, 12);			
  	gtk_widget_show (temp_widget);
@@ -554,7 +554,7 @@ setup_RAM_form(NautilusHardwareView *view)
 /* set up the widgetry for the IDE page */
 
 static void
-setup_IDE_form(NautilusHardwareView *view)
+setup_IDE_form (NautilusHardwareView *view)
 {
         char *message;
         GtkWidget *temp_widget;
@@ -567,10 +567,10 @@ setup_IDE_form(NautilusHardwareView *view)
         /* set up the title */  
         setup_form_title (view, NULL, "IDE");
         
-        message = "This is a placeholder for the IDE page.";
-        temp_widget = nautilus_label_new (message);
-	nautilus_label_make_larger (NAUTILUS_LABEL (temp_widget), 2);
-        nautilus_label_set_wrap(NAUTILUS_LABEL(temp_widget), TRUE);
+        message = _("This is a placeholder for the IDE page.");
+        temp_widget = eel_label_new (message);
+	eel_label_make_larger (EEL_LABEL (temp_widget), 2);
+        eel_label_set_wrap(EEL_LABEL(temp_widget), TRUE);
         
         gtk_box_pack_start(GTK_BOX(view->details->form), temp_widget, 0, 0, 12);            
         gtk_widget_show (temp_widget);
@@ -645,7 +645,7 @@ nautilus_hardware_view_drag_data_received (GtkWidget *widget, GdkDragContext *co
 	switch (info) {
         case TARGET_COLOR:
                 /* Let the background change based on the dropped color. */
-                nautilus_background_receive_dropped_color (nautilus_get_widget_background (widget),
+                eel_background_receive_dropped_color (eel_get_widget_background (widget),
                                                            widget, x, y, selection_data);
                 break;
                 
