@@ -57,7 +57,7 @@ typedef struct {
 
 static gboolean file_in_info_path (const char *file);
 
-/* This is a copy of nautilus_shell_quote. The best thing to do is to
+/* This is a copy of eel_shell_quote. The best thing to do is to
  * use the one on GNOME for GNOME 2.0, but we could also move this
  * into gnome-vfs or some other library so we could share it.
  */
@@ -117,7 +117,11 @@ help_uri_to_string (HelpURI *help_uri)
 
 	switch (help_uri->type) {
 	case SGML_FILE: case XML_FILE:
+#ifdef USE_GNOME_DB2HTML3
+		command = "gnome-db2html3";
+#else
                 command = "gnome-db2html2";
+#endif
 		if (help_uri->section != NULL) {
                         parameter = g_strconcat (help_uri->file, "?", help_uri->section, NULL);
                 } else {
@@ -129,10 +133,9 @@ help_uri_to_string (HelpURI *help_uri)
                 parameter = g_strdup (help_uri->file);
 		break;
 	case INFO_FILE:
-                command = "info2html2";
+                command = "gnome-info2html2";
                 parameter = g_strdup (help_uri->file);
 		break;
-
 	case HTML_FILE:
                 escaped = gnome_vfs_escape_path_string (help_uri->file);
 		if (help_uri->section == NULL) {
@@ -153,6 +156,11 @@ help_uri_to_string (HelpURI *help_uri)
 		g_assert_not_reached ();
                 return NULL;
 	}
+
+        if (parameter[0] == '-') {
+                g_free (parameter);
+                return NULL;
+        }
         
         /* Build a command line. */
         escaped = shell_quote (parameter);
