@@ -29,6 +29,33 @@
  * widget to display and munge html.
  */
 
+#include <config.h>
+#include "nautilus-mozilla-content-view.h"
+
+#include "bonobo-extensions.h"
+#include "gtkmozembed.h"
+#include "mozilla-components.h"
+#include "mozilla-events.h"
+#include "mozilla-preferences.h"
+#include "nautilus-mozilla-embed-extensions.h"
+#include <bonobo/bonobo-control.h>
+#include <bonobo/bonobo-ui-util.h>
+#include <eel/eel-glib-extensions.h>
+#include <eel/eel-gtk-extensions.h>
+#include <eel/eel-gtk-macros.h>
+#include <eel/eel-stock-dialogs.h>
+#include <gtk/gtksignal.h>
+#include <libgnome/gnome-i18n.h>
+#include <libgnomeui/gnome-dialog-util.h>
+#include <libgnomeui/gnome-dialog.h>
+#include <libgnomeui/gnome-stock.h>
+#include <libgnomevfs/gnome-vfs.h>
+#include <stdlib.h>
+
+#ifdef HAVE_AMMONITE
+#include <libtrilobite/libammonite-gtk.h>
+#endif
+
 #define nopeDEBUG_ramiro 1
 #define nopeDEBUG_mfleming 1
 #define nopeDEBUG_pepper 1
@@ -39,36 +66,6 @@
 #define DEBUG_MSG(x)
 #endif
 
-#include <config.h>
-#include "nautilus-mozilla-content-view.h"
-
-#include "gtkmozembed.h"
-
-#include "mozilla-preferences.h"
-#include "mozilla-components.h"
-#include "mozilla-events.h"
-#include "nautilus-mozilla-embed-extensions.h"
-#include "bonobo-extensions.h"
-
-#include <bonobo/bonobo-ui-util.h>
-#include <bonobo/bonobo-control.h>
-#include <gtk/gtksignal.h>
-#include <libgnome/gnome-i18n.h>
-#include <libgnomeui/gnome-stock.h>
-#include <libgnomevfs/gnome-vfs.h>
-#include <stdlib.h>
-#include <libgnomeui/gnome-dialog.h>
-#include <libgnomeui/gnome-dialog-util.h>
-
-#include <libnautilus-extensions/nautilus-stock-dialogs.h>
-#include <libnautilus-extensions/nautilus-file-utilities.h>
-
-#ifdef EAZEL_SERVICES
-#include <libtrilobite/libammonite-gtk.h>
-#endif
-
-#define NUM_ELEMENTS_IN_ARRAY(_a) (sizeof (_a) / sizeof ((_a)[0]))
-
 /* Code-copied from nsGUIEvent.h */
 
 enum nsEventStatus {  
@@ -210,7 +207,7 @@ static gint	string_list_get_index_of_string 		(const char			*string_list[],
 static void	pre_widget_initialize				(void);
 static void	post_widget_initialize				(void);
 
-#ifdef EAZEL_SERVICES
+#ifdef HAVE_AMMONITE
 
 /*
  * URL scheme hack for the eazel-services: scheme
@@ -221,7 +218,7 @@ static char *	eazel_services_scheme_to_http			(NautilusMozillaContentView	*view,
 
 static char *	eazel_services_scheme_from_http			(NautilusMozillaContentView	*view,
 				  				 const char			*uri);
-#endif /* EAZEL_SERVICES */
+#endif /* HAVE_AMMONITE */
 
 /* BonoboControl callbacks */
 static void bonobo_control_activate_callback (BonoboObject *control, gboolean state, gpointer callback_data);
@@ -229,32 +226,9 @@ static void bonobo_control_activate_callback (BonoboObject *control, gboolean st
 /***********************************************************************************/
 /***********************************************************************************/
 
-static GtkVBoxClass *parent_class = NULL;
-
-GtkType
-nautilus_mozilla_content_view_get_type (void)
-{
-	static GtkType mozilla_content_view_type = 0;
-	
-	if (!mozilla_content_view_type)
-	{
-		static const GtkTypeInfo mozilla_content_view_info =
-		{
-			"NautilusMozillaContentView",
-			sizeof (NautilusMozillaContentView),
-			sizeof (NautilusMozillaContentViewClass),
-			(GtkClassInitFunc) nautilus_mozilla_content_view_initialize_class,
-			(GtkObjectInitFunc) nautilus_mozilla_content_view_initialize,
-			/* reserved_1 */ NULL,
-			/* reserved_2 */ NULL,
-			(GtkClassInitFunc) NULL,
-		};
-		
-		mozilla_content_view_type = gtk_type_unique (GTK_TYPE_VBOX, &mozilla_content_view_info);
-	}
-	
-	return mozilla_content_view_type;
-}
+EEL_DEFINE_CLASS_BOILERPLATE (NautilusMozillaContentView,
+			      nautilus_mozilla_content_view,
+			      GTK_TYPE_VBOX);
 
 static void
 nautilus_mozilla_content_view_initialize_class (NautilusMozillaContentViewClass *klass)
@@ -263,8 +237,6 @@ nautilus_mozilla_content_view_initialize_class (NautilusMozillaContentViewClass
 	
 	object_class = GTK_OBJECT_CLASS (klass);
 
-	parent_class = gtk_type_class (GTK_TYPE_VBOX);
-	
 	object_class->destroy = nautilus_mozilla_content_view_destroy;
 
 	pre_widget_initialize ();
@@ -386,11 +358,9 @@ nautilus_mozilla_content_view_destroy (GtkObject *object)
 	cancel_pending_vfs_operation (view);
 
 	g_free (view->details);
-	
-	if (GTK_OBJECT_CLASS (parent_class)->destroy) {
-		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
-	}
 
+	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	
 	DEBUG_MSG (("-%s\n", __FUNCTION__));
 }
 
@@ -552,12 +522,13 @@ mozilla_view_create_charset_encoding_submenu (NautilusMozillaContentView *mozill
 		/* Add new encodings to the list only once */
 		if (encoding_group != NULL) {
 			if (!g_list_find_custom	(groups, encoding_group, (GCompareFunc) strcoll)) {
-				groups = g_list_append (groups, encoding_group);
+				groups = g_list_prepend (groups, encoding_group);
 			}
 		}
 		
 		g_free (encoding_title);
 	}
+	groups = g_list_reverse (groups);
 	
 	/* Create the encoding group submenus */
 	node = groups;
@@ -784,32 +755,20 @@ mozilla_title_changed_callback (GtkMozEmbed *mozilla, gpointer user_data)
 	DEBUG_MSG (("-%s\n", __FUNCTION__));
 }
 
-static GtkWindow *
-mozilla_get_containing_window (GtkMozEmbed *mozilla)
-{
-	GtkWidget *window;
-
-	window = gtk_widget_get_ancestor (GTK_WIDGET (mozilla), GTK_TYPE_WINDOW);
-	if (window == NULL) {
-		return NULL;
-	}
-
-	return GTK_WINDOW (window);
-}
-
 static void
 mozilla_new_window_callback (GtkMozEmbed *mozilla)
 {
-	GnomeDialog     *dialog;
-
-#ifdef DEBUG_pepper
-	g_warning ("Nautilus does not support JavaScript spawning of new windows!\n");
-#endif
-
-	dialog = nautilus_show_warning_dialog (_("A JavaScript function (small software program) on this page tried to open a new window, but nautilus does not support the opening of new windows by JavaScript.\n\nTry viewing the page in a different web browser, such as Mozilla or Netscape."),
-					     _("Nautilus Mozilla View Warning"),
-					     mozilla_get_containing_window (mozilla));
+	static GnomeDialog *dialog;
 
+	if (dialog == NULL) {
+		dialog = eel_show_warning_dialog (_("A JavaScript function (small software program) on this page "
+						    "tried to open a new window, but Nautilus does not support the "
+						    "opening new windows by JavaScript.\n\n"
+						    "Try viewing the page in a different web browser, such as Mozilla."),
+						  _("Nautilus JavaScript Warning"),
+						  NULL);
+		eel_nullify_when_destroyed (&dialog);
+	}
 }
 
 static void
@@ -1347,11 +1306,11 @@ translate_uri_nautilus_to_mozilla (NautilusMozillaContentView *view, const char
 	g_return_val_if_fail (uri != NULL, NULL);
 
 
-#ifdef EAZEL_SERVICES
+#ifdef HAVE_AMMONITE
 	if (0 == strncmp (uri, "eazel-services:", strlen ("eazel-services:"))) {
 		ret = eazel_services_scheme_to_http (view, uri);
 	} else
-#endif /* EAZEL_SERVICES */
+#endif /* HAVE_AMMONITE */
 		{
 		ret = g_strdup (uri);
 	}
@@ -1363,11 +1322,11 @@ translate_uri_nautilus_to_mozilla (NautilusMozillaContentView *view, const char
 static char *
 translate_uri_mozilla_to_nautilus (NautilusMozillaContentView *view, const char *uri)
 {
-#ifdef EAZEL_SERVICES
+#ifdef HAVE_AMMONITE
 	return eazel_services_scheme_from_http (view, uri);
 #else
 	return g_strdup (uri);
-#endif /* EAZEL_SERVICES */
+#endif /* HAVE_AMMONITE */
 }
 
 #ifdef BUSY_CURSOR
@@ -1847,7 +1806,7 @@ should_uri_navigate_bypass_nautilus (const char *uri)
 
 	g_return_val_if_fail (uri != NULL, FALSE);
 	
-	return string_list_get_index_of_string (handled_by_nautilus, NUM_ELEMENTS_IN_ARRAY (handled_by_nautilus),
+	return string_list_get_index_of_string (handled_by_nautilus, EEL_N_ELEMENTS (handled_by_nautilus),
 						uri) != STRING_LIST_NOT_FOUND;
 }
 
@@ -1864,7 +1823,7 @@ should_mozilla_load_uri_directly (const char *uri)
 		"eazel-services"
 	};
 
-	return string_list_get_index_of_string (handled_by_mozilla, NUM_ELEMENTS_IN_ARRAY (handled_by_mozilla),
+	return string_list_get_index_of_string (handled_by_mozilla, EEL_N_ELEMENTS (handled_by_mozilla),
 						uri) != STRING_LIST_NOT_FOUND;
 }
 
@@ -1967,7 +1926,7 @@ post_widget_initialize (void)
 }
 
 
-#ifdef EAZEL_SERVICES
+#ifdef HAVE_AMMONITE
 
 /*
  * URL scheme hack for the eazel-services: scheme
@@ -2046,4 +2005,4 @@ eazel_services_scheme_from_http	(NautilusMozillaContentView	*view,
 	return ret;
 }
 
-#endif /* EAZEL_SERVICES */
+#endif /* HAVE_AMMONITE */
