@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 
 /* 
- * Copyright (C) 2000 Eazel, Inc
+ * Copyright (C) 2000, 2001 Eazel, Inc
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -29,15 +29,16 @@
 #include "nautilus-tree-node-private.h"
 #include <gtk/gtksignal.h>
 #include <libgnomevfs/gnome-vfs.h>
-#include <libnautilus-extensions/nautilus-file-attributes.h>
-#include <libnautilus-extensions/nautilus-gtk-macros.h>
+#include <libnautilus-private/nautilus-file-attributes.h>
+#include <eel/eel-glib-extensions.h>
+#include <eel/eel-gtk-macros.h>
 #include <stdio.h>
 #include <string.h>
 
 enum {
-	NODE_ADDED,
 	NODE_CHANGED,
 	NODE_REMOVED,
+	NODE_BEING_RENAMED,
 	DONE_LOADING_CHILDREN,
 	LAST_SIGNAL
 };
@@ -49,10 +50,14 @@ struct NautilusTreeModelDetails {
 	GHashTable       *file_to_node_map;
 
 	GList            *monitor_clients;
+	GList		 *unparented_nodes;
 
 	NautilusTreeNode *root_node;
 	gboolean          root_node_reported;
 	gint              root_node_changed_signal_id;
+
+	GHashTable       *changed_files;
+	GHashTable       *done_loading_files;
 };
 
 
@@ -83,14 +88,11 @@ static void nautilus_tree_model_root_node_file_monitor           (NautilusFile
 static void nautilus_tree_model_directory_files_changed_callback (NautilusDirectory *directory,
 								  GList             *added_files,
 								  NautilusTreeModel *model);
-static void nautilus_tree_model_directory_files_added_callback   (NautilusDirectory *directory,
-								  GList             *added_files,
-								  NautilusTreeModel *model);
 static void nautilus_tree_model_directory_done_loading_callback  (NautilusDirectory *directory,
 								  NautilusTreeModel *model);
 
 
-NAUTILUS_DEFINE_CLASS_BOILERPLATE (NautilusTreeModel, nautilus_tree_model, GTK_TYPE_OBJECT)
+EEL_DEFINE_CLASS_BOILERPLATE (NautilusTreeModel, nautilus_tree_model, GTK_TYPE_OBJECT)
 
 /* infrastructure stuff */
 
@@ -103,14 +105,6 @@ nautilus_tree_model_initialize_class (gpointer klass)
 	
 	object_class->destroy = nautilus_tree_model_destroy;
 
-	signals[NODE_ADDED] =
-		gtk_signal_new ("node_added",
-				GTK_RUN_LAST,
-				object_class->type,
-				GTK_SIGNAL_OFFSET (NautilusTreeModelClass, node_added),
-				gtk_marshal_NONE__POINTER,
-				GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
-
 	signals[NODE_CHANGED] =
 		gtk_signal_new ("node_changed",
 				GTK_RUN_LAST,
@@ -127,6 +121,14 @@ nautilus_tree_model_initialize_class (gpointer klass)
 				gtk_marshal_NONE__POINTER,
 				GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
 
+	signals[NODE_BEING_RENAMED] =
+		gtk_signal_new ("node_being_renamed",
+				GTK_RUN_LAST,
+				object_class->type,
+				GTK_SIGNAL_OFFSET (NautilusTreeModelClass, node_removed),
+				gtk_marshal_NONE__POINTER_POINTER,
+				GTK_TYPE_NONE, 2, GTK_TYPE_STRING, GTK_TYPE_STRING);
+
 	signals[DONE_LOADING_CHILDREN] =
 		gtk_signal_new ("done_loading_children",
 				GTK_RUN_LAST,
@@ -151,6 +153,18 @@ nautilus_tree_model_initialize (gpointer object, gpointer klass)
 	model->details->file_to_node_map = g_hash_table_new (NULL, NULL);
 }
 
+static void
+destroy_file_hash (GHashTable *hash)
+{
+	if (hash == NULL) {
+		return;
+	}
+	eel_g_hash_table_destroy_deep_custom
+		(hash,
+		 (GFunc) nautilus_file_unref, NULL,
+		 NULL, NULL);
+}
+
 static void
 nautilus_tree_model_destroy (GtkObject *object)
 {
@@ -166,12 +180,16 @@ nautilus_tree_model_destroy (GtkObject *object)
 	remove_all_nodes (model);
 
 	g_list_free (model->details->monitor_clients);
+	g_list_free (model->details->unparented_nodes);
 
 	g_hash_table_destroy (model->details->file_to_node_map);
 
+	destroy_file_hash (model->details->changed_files);
+	destroy_file_hash (model->details->done_loading_files);
+
 	g_free (model->details);
 	
-	NAUTILUS_CALL_PARENT_CLASS (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 
@@ -276,6 +294,9 @@ remove_all_nodes (NautilusTreeModel *model)
 		model->details->root_node = NULL;
 	}
 	model->details->root_node_reported = FALSE;
+
+	g_list_free (model->details->unparented_nodes);
+	model->details->unparented_nodes = NULL;
 }
 
 void
@@ -288,6 +309,9 @@ nautilus_tree_model_monitor_add (NautilusTreeModel         *model,
 	GList *reporting_queue, *link;
 	GList *monitor_attributes;
 	
+	g_return_if_fail (NAUTILUS_IS_TREE_MODEL (model));
+	g_return_if_fail (initial_nodes_callback != NULL);
+
 	reporting_queue = NULL;
 
 	/* If we just (re)started monitoring the whole tree, make sure
@@ -305,11 +329,9 @@ nautilus_tree_model_monitor_add (NautilusTreeModel         *model,
 			 model);
 		
 		monitor_attributes = g_list_prepend (NULL, NAUTILUS_FILE_ATTRIBUTE_IS_DIRECTORY);
-
 		nautilus_file_monitor_add (nautilus_tree_node_get_file (model->details->root_node),
 					   model,
 					   monitor_attributes);
-
 		g_list_free (monitor_attributes);
 	}
 
@@ -345,6 +367,8 @@ void
 nautilus_tree_model_monitor_remove (NautilusTreeModel         *model,
 				    gconstpointer              client)
 {
+	g_return_if_fail (NAUTILUS_IS_TREE_MODEL (model));
+
 	model->details->monitor_clients = g_list_remove (model->details->monitor_clients, (gpointer) client);
 
 	if (model->details->root_node_reported) {
@@ -368,6 +392,8 @@ static gboolean
 nautilus_tree_model_node_has_monitor_clients (NautilusTreeModel         *model,
 					      NautilusTreeNode          *node)
 {
+	g_return_val_if_fail (NAUTILUS_IS_TREE_MODEL (model), FALSE);
+
 	return (node->details->monitor_clients != NULL);
 }
 
@@ -382,12 +408,15 @@ nautilus_tree_model_node_begin_monitoring_no_connect (NautilusTreeModel
 
 	directory = nautilus_tree_node_get_directory (node);
 
+	if (force_reload) {
+		nautilus_directory_force_reload (directory);
+	}
+
 	monitor_attributes = g_list_prepend (NULL, NAUTILUS_FILE_ATTRIBUTE_IS_DIRECTORY);
 	nautilus_directory_file_monitor_add (directory,
 					     model,
 					     TRUE, TRUE,
-					     monitor_attributes,
-					     force_reload);
+					     monitor_attributes);
 	g_list_free (monitor_attributes);
 }
 
@@ -406,7 +435,7 @@ nautilus_tree_model_node_begin_monitoring (NautilusTreeModel         *model,
 	node->details->files_added_id = gtk_signal_connect 
 		(GTK_OBJECT (directory),
 		 "files_added",
-		 nautilus_tree_model_directory_files_added_callback,
+		 nautilus_tree_model_directory_files_changed_callback,
 		 model);
 	
 	node->details->files_changed_id = gtk_signal_connect 
@@ -428,6 +457,9 @@ static void
 nautilus_tree_model_node_end_monitoring (NautilusTreeModel         *model,
 					 NautilusTreeNode          *node)
 {
+	g_return_if_fail (NAUTILUS_IS_TREE_MODEL (model));
+	g_return_if_fail (NAUTILUS_IS_TREE_NODE (node));
+
 	gtk_signal_disconnect (GTK_OBJECT (node->details->directory), node->details->files_added_id);
 	gtk_signal_disconnect (GTK_OBJECT (node->details->directory), node->details->files_changed_id);
 	gtk_signal_disconnect (GTK_OBJECT (node->details->directory), node->details->done_loading_id);
@@ -448,6 +480,13 @@ nautilus_tree_model_monitor_node (NautilusTreeModel         *model,
 				  gconstpointer              client,
 				  gboolean                   force_reload)
 {
+	GList *p;
+	GList *lost_nodes;
+	NautilusDirectory *directory;
+
+	g_return_if_fail (NAUTILUS_IS_TREE_MODEL (model));
+	g_return_if_fail (NAUTILUS_IS_TREE_NODE (node));
+
 	if (!nautilus_file_is_directory (nautilus_tree_node_get_file (node))) {
 		report_done_loading (model, node);
 		return;
@@ -463,6 +502,21 @@ nautilus_tree_model_monitor_node (NautilusTreeModel         *model,
 		node->details->monitor_clients = g_list_prepend (node->details->monitor_clients, 
 								 (gpointer) client);
 	}
+
+	/* Check if any files got moved out of this directory
+	 * while the node was collapsed.
+	 */
+	directory = nautilus_tree_node_get_directory (node);
+	lost_nodes = NULL;
+	for (p = nautilus_tree_node_get_children (node); p != NULL; p = p->next) {
+		if (!nautilus_directory_contains_file (directory, nautilus_tree_node_get_file (p->data))) {
+			lost_nodes = g_list_prepend (lost_nodes, p->data);
+		}
+	}
+	for (p = lost_nodes; p != 0; p = p->next) {
+		report_node_removed (model, p->data);
+	}
+	g_list_free (lost_nodes);
 }
 
 
@@ -471,6 +525,9 @@ nautilus_tree_model_stop_monitoring_node (NautilusTreeModel *model,
 					  NautilusTreeNode  *node,
 					  gconstpointer      client)
 {
+	g_return_if_fail (NAUTILUS_IS_TREE_MODEL (model));
+	g_return_if_fail (NAUTILUS_IS_TREE_NODE (node));
+
 	if (!nautilus_file_is_directory (nautilus_tree_node_get_file (node)) || node->details->monitor_clients == NULL) {
 		return;
 	}
@@ -494,6 +551,9 @@ nautilus_tree_model_stop_monitoring_node_recursive (NautilusTreeModel *model,
 {
 	GList *p;
 
+	g_return_if_fail (NAUTILUS_IS_TREE_MODEL (model));
+	g_return_if_fail (NAUTILUS_IS_TREE_NODE (node));
+
 	nautilus_tree_model_stop_monitoring_node (model, node, client);
 
 	for (p = nautilus_tree_node_get_children (node); p != NULL; p = p->next) {
@@ -519,6 +579,9 @@ nautilus_tree_model_get_node (NautilusTreeModel *model,
 	NautilusFile *file;
 	NautilusTreeNode *node;
 
+	g_return_val_if_fail (NAUTILUS_IS_TREE_MODEL (model), NULL);
+	g_return_val_if_fail (uri != NULL, NULL);
+
 	file = nautilus_file_get (uri);
 	
 	if (file == NULL) {
@@ -600,6 +663,54 @@ report_root_node_if_possible (NautilusTreeModel *model)
 	}
 }
 
+static void
+register_unparented_node (NautilusTreeModel *model, NautilusTreeNode *node)
+{
+	if (!nautilus_tree_node_is_toplevel (node) && g_list_find (model->details->unparented_nodes, node) == NULL) {
+		model->details->unparented_nodes = g_list_prepend (model->details->unparented_nodes, node);
+	}
+}
+
+static void
+forget_unparented_node (NautilusTreeModel *model, NautilusTreeNode *node)
+{
+	model->details->unparented_nodes = g_list_remove (model->details->unparented_nodes, node);
+}
+
+static void
+connect_unparented_nodes (NautilusTreeModel *model, NautilusTreeNode *parent)
+{
+	NautilusDirectory *parent_directory;
+	char *parent_uri;
+	NautilusTreeNode *node;
+	GList *p, *to_parent;
+
+	parent_uri = nautilus_file_get_uri (parent->details->file);
+	parent_directory = nautilus_directory_get (parent_uri);
+	g_free (parent_uri);
+
+	if (parent_directory != NULL) {
+		to_parent = NULL;
+
+		for (p = model->details->unparented_nodes; p != NULL; p = p->next) {
+			node = p->data;
+			if (nautilus_directory_contains_file (parent_directory, node->details->file)) {
+				to_parent = g_list_prepend (to_parent, node);
+			}
+		}
+
+		for (p = to_parent; p != NULL; p = p->next) {
+			node = p->data;
+			nautilus_tree_node_set_parent (node, parent);
+			model->details->unparented_nodes = g_list_remove (model->details->unparented_nodes, node);
+		}
+
+		g_list_free (to_parent);
+
+		nautilus_directory_unref (parent_directory);
+	}
+}
+
 
 static void
 report_node_changed (NautilusTreeModel *model,
@@ -643,6 +754,8 @@ report_node_changed (NautilusTreeModel *model,
 			if (parent_node != NULL) {
 				nautilus_tree_node_set_parent (node,
 							       parent_node);
+			} else {
+				register_unparented_node (model, node);
 			}
 
 			g_free (parent_uri);
@@ -654,8 +767,11 @@ report_node_changed (NautilusTreeModel *model,
 				     node);
 
 		gtk_signal_emit (GTK_OBJECT (model),
-				 signals[NODE_ADDED],
+				 signals[NODE_CHANGED],
 				 node);
+
+		connect_unparented_nodes (model, node);
+
 	} else {
 		/* really changed */
 
@@ -666,16 +782,23 @@ report_node_changed (NautilusTreeModel *model,
 			gtk_signal_emit (GTK_OBJECT (model),
 					 signals[NODE_CHANGED],
 					 node);
-			g_free (file_uri);
 		} else {
 			/* A move or rename - model it as a remove followed by an add */
 
 			gtk_object_ref (GTK_OBJECT (node));
 
+
+			/* Let the view know that the rename is happening, this allows
+			 * it to propagate the expansion state from the old name to the
+			 * new name
+			 */
+			gtk_signal_emit (GTK_OBJECT (model),
+					 signals[NODE_BEING_RENAMED],
+					 node->details->uri, file_uri);
+
 			report_node_removed (model, node);
-			
-			g_free (node->details->uri);
-			node->details->uri = file_uri;
+
+			nautilus_tree_node_update_uri (node);
 			
 #if 0
 			if (node->details->directory != NULL) {
@@ -692,6 +815,8 @@ report_node_changed (NautilusTreeModel *model,
 
 			gtk_object_unref (GTK_OBJECT (node));
 		}
+
+		g_free (file_uri);
 	}
 	
 	g_free (node_uri);
@@ -703,6 +828,7 @@ report_node_removed_internal (NautilusTreeModel *model,
 			      gboolean signal)
 {
 	NautilusTreeNode *parent_node;
+	GList *p;
 
 	if (node == NULL) {
 		return;
@@ -717,9 +843,15 @@ report_node_removed_internal (NautilusTreeModel *model,
 			nautilus_tree_node_remove_from_parent (node);
 		}
 
+		for (p = node->details->children; p != NULL; p = p->next) {
+			register_unparented_node (model, p->data);
+		}
+		nautilus_tree_node_remove_children (node);
+
 		g_hash_table_remove (model->details->file_to_node_map, 
 				     nautilus_tree_node_get_file (node));
 	
+		forget_unparented_node (model, node);
 
 		if (signal) {
 			gtk_signal_emit (GTK_OBJECT (model),
@@ -764,6 +896,50 @@ nautilus_tree_model_root_node_file_monitor (NautilusFile      *file,
 	}
 }
 
+static void
+process_file_change (NautilusTreeModel *model,
+		     NautilusFile *file)
+{
+	NautilusTreeNode *node;
+
+	node = nautilus_tree_model_get_node_from_file (model, file);
+	
+	if (nautilus_file_is_gone (file)) {
+		if (node != NULL) {
+			report_node_removed (model, node);
+		}
+	} else {
+		if (node == NULL) {
+			node = nautilus_tree_node_new (file);
+		} else {
+			gtk_object_ref (GTK_OBJECT (node));
+		}
+		report_node_changed (model, node);
+		gtk_object_unref (GTK_OBJECT (node));
+	}
+}
+
+static void
+process_directory_done_loading (NautilusTreeModel *model,
+				NautilusFile *file)
+{
+	NautilusTreeNode *node;
+
+	node = nautilus_tree_model_get_node_from_file (model, file);
+	if (node != NULL) {
+		report_done_loading (model, node);
+	}
+}
+
+static void
+add_file_to_hash (GHashTable *hash,
+		  NautilusFile *file)
+{
+	if (g_hash_table_lookup (hash, file) == NULL) {
+		nautilus_file_ref (file);
+		g_hash_table_insert (hash, file, file);
+	}
+}
 
 static void
 nautilus_tree_model_directory_files_changed_callback (NautilusDirectory        *directory,
@@ -772,70 +948,88 @@ nautilus_tree_model_directory_files_changed_callback (NautilusDirectory        *
 {
 	GList *p;
 	NautilusFile *file;
-	NautilusTreeNode *node;
-	char *uri;
 
 	for (p = changed_files; p != NULL; p = p->next) {
 		file = NAUTILUS_FILE (p->data);
-		
-		node = nautilus_tree_model_get_node_from_file (model, file);
 
-		if (node == NULL) {
-			/* Do we need to add this node? */
-			uri = nautilus_file_get_uri (file);
-			g_free (uri);
+		if (model->details->changed_files != NULL) {
+			add_file_to_hash (model->details->changed_files, file);
 		} else {
-			if (!nautilus_directory_contains_file (directory, file)
-			    || nautilus_file_is_gone (file)) {
-				report_node_removed (model, node);
-			} else {			
-				report_node_changed (model, node);
-			}
+			process_file_change (model, file);
 		}
 	} 
 }
 
-static void
-nautilus_tree_model_directory_files_added_callback (NautilusDirectory        *directory,
-						    GList                    *added_files,
-						    NautilusTreeModel        *model)
-{
-	GList *p;
-	NautilusFile     *file;
-	NautilusTreeNode *node;
-
-	for (p = added_files; p != NULL; p = p->next) {
-		file = (NautilusFile *) p->data;
-		
-		node = nautilus_tree_model_get_node_from_file (model, file);
-
-		if (node == NULL) {
-			node = nautilus_tree_node_new (file);
-		} else {
-			gtk_object_ref (GTK_OBJECT (node));
-		}			
-		
-		report_node_changed (model, node);
-
-		gtk_object_unref (GTK_OBJECT (node));
-	}
-}
-
-
 static void
 nautilus_tree_model_directory_done_loading_callback (NautilusDirectory        *directory,
 						     NautilusTreeModel        *model)
 {
 	NautilusFile *file;
-	NautilusTreeNode *node;
 
 	file = nautilus_directory_get_corresponding_file (directory);
-	node = nautilus_tree_model_get_node_from_file (model, file);
-	nautilus_file_unref (file);
 
-	if (node != NULL) {
-		report_done_loading (model, node);
+	if (model->details->done_loading_files != NULL) {
+		add_file_to_hash (model->details->done_loading_files, file);
 	} else {
-		g_warning ("Got done loading notification for nonexistent node %s", nautilus_directory_get_uri (directory));
+		process_directory_done_loading (model, file);
+	}
+
+	nautilus_file_unref (file);
+}
+
+static void
+process_one_changed_file (gpointer key, gpointer value, gpointer callback_data)
+{
+	g_assert (NAUTILUS_IS_FILE (key));
+	g_assert (key == value);
+	g_assert (NAUTILUS_IS_TREE_MODEL (callback_data));
+
+	process_file_change (callback_data, key);
+}
+
+static void
+process_one_done_loading_file (gpointer key, gpointer value, gpointer callback_data)
+{
+	g_assert (NAUTILUS_IS_FILE (key));
+	g_assert (key == value);
+	g_assert (NAUTILUS_IS_TREE_MODEL (callback_data));
+
+	process_directory_done_loading (callback_data, key);
+}
+
+void
+nautilus_tree_model_set_defer_notifications  (NautilusTreeModel *model,
+					      gboolean defer)
+{
+	gboolean already_deferring;
+	GHashTable *changed, *done_loading;
+
+	g_return_if_fail (NAUTILUS_IS_TREE_MODEL (model));
+	g_return_if_fail (defer == FALSE || defer == TRUE);
+
+	already_deferring = model->details->changed_files != NULL;
+	if (already_deferring == defer) {
+		return;
+	}
+
+	if (defer) {
+		model->details->changed_files = g_hash_table_new (NULL, NULL);
+		model->details->done_loading_files = g_hash_table_new (NULL, NULL);
+	} else {
+		changed = model->details->changed_files;
+		done_loading = model->details->done_loading_files;
+
+		model->details->changed_files = NULL;
+		model->details->done_loading_files = NULL;
+
+		g_hash_table_foreach (changed,
+				      process_one_changed_file,
+				      model);
+		g_hash_table_foreach (done_loading,
+				      process_one_done_loading_file,
+				      model);
+
+		destroy_file_hash (changed);
+		destroy_file_hash (done_loading);
 	}
 }
