@@ -69,6 +69,7 @@ typedef enum {
 	NAUTILUS_VOLUME_MINIX,
 	NAUTILUS_VOLUME_MSDOS,
 	NAUTILUS_VOLUME_NFS,
+	NAUTILUS_VOLUME_PROC,
 	NAUTILUS_VOLUME_REISER,
 	NAUTILUS_VOLUME_SMB,
 	NAUTILUS_VOLUME_UDF,
@@ -76,6 +77,7 @@ typedef enum {
 	NAUTILUS_VOLUME_UNSDOS,
 	NAUTILUS_VOLUME_VFAT,
 	NAUTILUS_VOLUME_XENIX,
+	NAUTILUS_VOLUME_XFS,
 	NAUTILUS_VOLUME_XIAFS,
 	NAUTILUS_VOLUME_UNKNOWN
 } NautilusVolumeType;
