@@ -38,17 +38,18 @@
 #ifdef HAVE_MEDUSA
 #include <libmedusa/medusa-indexed-search.h>
 #include <libmedusa/medusa-unindexed-search.h>
-#include <libmedusa/medusa-index-service.h>
+#include <libmedusa/medusa-index-progress.h>
 #endif
-#include <libnautilus-extensions/nautilus-bonobo-extensions.h>
-#include <libnautilus-extensions/nautilus-file-attributes.h>
-#include <libnautilus-extensions/nautilus-file-utilities.h>
-#include <libnautilus-extensions/nautilus-glib-extensions.h>
-#include <libnautilus-extensions/nautilus-gnome-extensions.h>
-#include <libnautilus-extensions/nautilus-gtk-macros.h>
-#include <libnautilus-extensions/nautilus-search-uri.h>
-#include <libnautilus-extensions/nautilus-stock-dialogs.h>
-#include <libnautilus-extensions/nautilus-string.h>
+#include <libnautilus-private/nautilus-bonobo-extensions.h>
+#include <libnautilus-private/nautilus-file-attributes.h>
+#include <libnautilus-private/nautilus-file-utilities.h>
+#include <libnautilus-private/nautilus-medusa-support.h>
+#include <eel/eel-glib-extensions.h>
+#include <eel/eel-gnome-extensions.h>
+#include <eel/eel-gtk-macros.h>
+#include <libnautilus-private/nautilus-search-uri.h>
+#include <eel/eel-stock-dialogs.h>
+#include <eel/eel-string.h>
 
 /* FIXME bugzilla.eazel.com 2815: This code uses part of the
  * NautilusSearchBarCriterion class, which is really for complex
@@ -82,100 +83,120 @@ static void	real_removing_file 			 (FMListView 	   *view,
 static gboolean real_file_still_belongs 		 (FMListView 	   *view, 
 							  NautilusFile 	   *file);
 static int  	real_get_number_of_columns           	 (FMListView       *list_view);
+static int  	real_get_emblems_column                	 (FMListView       *list_view);
 static int  	real_get_link_column                 	 (FMListView       *list_view);
 static char *   real_get_default_sort_attribute      	 (FMListView       *view);
 static void 	real_get_column_specification        	 (FMListView       *list_view,
 						      	  int               column_number,
 						      	  FMListViewColumn *specification);
-static NautilusStringList * real_get_emblem_names_to_exclude         (FMDirectoryView  *view);
+static EelStringList * real_get_emblem_names_to_exclude         (FMDirectoryView  *view);
 static void	real_file_limit_reached 		 (FMDirectoryView  *view);
 static void	real_merge_menus 		     	 (FMDirectoryView  *view);
-static gboolean real_supports_creating_files		 (FMDirectoryView  *view);
+static gboolean real_is_read_only			 (FMDirectoryView  *view);
 static gboolean real_accepts_dragged_files		 (FMDirectoryView  *view);
 static gboolean real_supports_properties 	     	 (FMDirectoryView  *view);
 static void 	load_location_callback               	 (NautilusView 	   *nautilus_view, 
 						      	  char 		   *location);
 static void	real_update_menus 		     	 (FMDirectoryView  *view);
 #ifdef HAVE_MEDUSA
-static void     display_indexed_search_problems_dialog   (gboolean unindexed_search_is_available);
+static void     display_system_services_are_disabled_dialog           (gboolean unindexed_search_is_available);
+static void     display_indexed_search_problems_dialog                (gboolean unindexed_search_is_available);
 #endif
 static void	reveal_selected_items_callback 		 (BonoboUIComponent *component, 
 							  gpointer 	    user_data, 
 							  const char 	   *verb);
 
 
-NAUTILUS_DEFINE_CLASS_BOILERPLATE (FMSearchListView,
+EEL_DEFINE_CLASS_BOILERPLATE (FMSearchListView,
 				   fm_search_list_view,
 				   FM_TYPE_LIST_VIEW)
 
+
+#ifdef HAVE_MEDUSA
+static void
+report_index_age_as_status (NautilusView *nautilus_view)
+{
+	char *last_indexing_time, *status_string;
+	
+	last_indexing_time = nautilus_indexing_info_get_last_index_time ();
+	if (last_indexing_time) {
+		status_string = g_strdup_printf (_("Search results may not include items modified after %s, "
+						   "when your drive was last indexed."),
+						 last_indexing_time);
+		
+		g_free (last_indexing_time);
+		nautilus_view_report_status (nautilus_view, status_string);
+		g_free (status_string);
+	}
+}
+#endif
+
 static void
 load_location_callback (NautilusView *nautilus_view, char *location)
 {
 #ifdef HAVE_MEDUSA
-	char *last_indexing_time, *status_string;
 	char *unescaped_location;
 	gboolean unindexed_search_is_available_for_uri;
 	gboolean indexed_search_is_available;
 
-	indexed_search_is_available = medusa_indexed_search_is_available () == GNOME_VFS_OK;
-	if (indexed_search_is_available) {
-		last_indexing_time = nautilus_indexing_info_get_last_index_time ();
-		if (last_indexing_time) {
-			status_string = g_strdup_printf (_("Search results may not include items modified after %s, when your drive was last indexed."),
-							 last_indexing_time);
-			
-			g_free (last_indexing_time);
-			nautilus_view_report_status (nautilus_view, status_string);
-			g_free (status_string);
-		}
-	}
-	if (!indexed_search_is_available) {
-		unescaped_location = gnome_vfs_unescape_string (location, NULL);
-		unindexed_search_is_available_for_uri = (medusa_unindexed_search_is_available_for_uri (unescaped_location) == GNOME_VFS_OK);
-		g_free (unescaped_location);
-		display_indexed_search_problems_dialog (unindexed_search_is_available_for_uri);
-	}
-#else
-	nautilus_error_dialog (_("Sorry, but the Medusa search service is not available because it is not installed."),
-			       _("Search Service Not Available"),
-			       NULL);
-#endif
 
 	nautilus_view_set_title (nautilus_view, _("Search Results"));
+
+	unescaped_location = gnome_vfs_unescape_string (location, NULL);
+	unindexed_search_is_available_for_uri = (medusa_unindexed_search_is_available_for_uri (unescaped_location) == GNOME_VFS_OK);
+	g_free (unescaped_location);
+
+	if (!nautilus_medusa_services_are_enabled ()) {
+		display_system_services_are_disabled_dialog (unindexed_search_is_available_for_uri);
+	}
+	else {
+		/* Fast (indexed) searching is enabled */
+		indexed_search_is_available = medusa_indexed_search_is_available () == GNOME_VFS_OK;
+
+		if (indexed_search_is_available) {
+			report_index_age_as_status (nautilus_view);
+		}
+		else {
+
+			display_indexed_search_problems_dialog (unindexed_search_is_available_for_uri);
+		}
+	}
+#else
+	eel_show_error_dialog (_("Sorry, but the Medusa search service is not available because it is not installed."),
+			            _("Search Service Not Available"),
+			            NULL);
+#endif
+
+
 }
 
 /* FIXME bugzilla.eazel.com 5057: GnomeVFSResults may not be the
    best way to communicate an error code to
    a view */
 static void
-load_error_callback (FMDirectoryView *nautilus_view, 
-		     GnomeVFSResult result,
-		     gpointer callback_data)
+real_load_error (FMDirectoryView *nautilus_view, 
+		 GnomeVFSResult result)
 {
 	GnomeDialog *load_error_dialog;
 	char *error_string;
+
+	/* Do not call parent's function; we handle all search errors
+	 * here and don't want fm-directory-view's default handling.
+	 */
 	
 	switch (result) {
 	case GNOME_VFS_ERROR_SERVICE_OBSOLETE:
-		/* FIXME bugzilla.eazel.com 5058: Should be two messages, one for each of whether
-		   "slow complete search" turned on or not */
-		load_error_dialog = nautilus_yes_no_dialog (_("The search you have selected "
-							      "is newer than the index on your "
-							      "system.  The search will return "
-							      "no results right now.  Would you like "
-							      "to create a new index now?"),
-							    _("Search for items that are too new"),
-							    _("Create a new index"),
-							    _("Don't create index"),
-							    NULL);
-		gtk_signal_connect (GTK_OBJECT (nautilus_gnome_dialog_get_button_by_index
-						(load_error_dialog, GNOME_OK)),
-				    "clicked",
-				    nautilus_indexing_info_request_reindex,
-				    NULL);
+		load_error_dialog = eel_show_info_dialog (_("The search you have selected "
+							    "is newer than the index on your "
+							    "system.  The search will return "
+							    "no results right now.  You can create a new "
+							    " index by running \"medusa-indexd\" as root "
+							    "on the command line."),
+							  _("Search for items that are too new"),
+							  NULL);
 		break;
 	case GNOME_VFS_ERROR_TOO_BIG:
-		nautilus_error_dialog (_("Every indexed file on your computer "
+		eel_show_error_dialog (_("Every indexed file on your computer "
 					 "matches the criteria you selected. "
 					 "You can check the spelling on your selections "
 					 "or add more criteria to narrow your results."),
@@ -183,16 +204,25 @@ load_error_callback (FMDirectoryView *nautilus_view,
 				       NULL);
 		break;
 	case GNOME_VFS_ERROR_SERVICE_NOT_AVAILABLE:
-		/* We've handled this case in load_location_callback */
+		/* FIXME: This dialog does not get shown because a slow search
+		   will be performed and will not return an error.  */
+		eel_show_error_dialog (_("Find cannot open your file system index.  "
+					 "Your index may be missing or corrupt.  You can "
+					 "create a new index by running \"medusa-indexd\" as root "
+					 "on the command line."),
+				       _("Error reading file index"),
+				       NULL);
+		break;
+	case GNOME_VFS_ERROR_CANCELLED:
 		break;
 	default:
 		error_string = g_strdup_printf (_("An error occurred while loading "
 							  "this search's contents: "
 							  "%s"),
 							gnome_vfs_result_to_string (result));
-		nautilus_error_dialog (error_string,
-				       _("Error during search"),
-				       NULL);
+		eel_show_error_dialog (error_string,
+				            _("Error during search"),
+				            NULL);
 		g_free (error_string);
 		
 	}
@@ -203,16 +233,12 @@ load_error_callback (FMDirectoryView *nautilus_view,
 static void
 display_indexed_search_problems_dialog (gboolean backup_search_is_available)
 {
-
-	GnomeDialog *index_problem_dialog;
 	const char *error_string, *title_string;
-	MedusaIndexingRequestResult index_service_availability;
-	GtkButton *create_index_button;
 
 	if (medusa_indexed_search_system_index_files_look_available ()) {
 		/* There is an index on the system, but there is no
 		   way to run a search anyways.  The system is
-		   confused.  Tell the user this */
+		   confused.  Tell the user this. */
 		error_string = backup_search_is_available 
 			? N_("To do a fast search, Find requires an index "
 			     "of the files on your system.  "
@@ -220,67 +246,29 @@ display_indexed_search_problems_dialog (gboolean backup_search_is_available)
 			     "so a slower search will be performed that "
 			     "doesn't use the index.") 
 			: N_("To do a content search, Find requires an index "
-			     "of thie files on your system.  "
+			     "of the files on your system.  "
 			     "Find can't access your index right now. ");
 		title_string = backup_search_is_available 
 			?  N_("Fast searches are not available")
 			:  N_("Content searches are not available");
-		nautilus_error_dialog_with_details (error_string,
+		eel_show_error_dialog_with_details (error_string,
 						    title_string,
 						    _("Your index files are available "
 						      "but the Medusa search daemon, which handles "
 						      "index requests, isn't running.  "
 						      "To start this program, log in as root and "
-						      "enter this command at the command line: "
+						      "enter this command at the command line:\n\n"
 						      "medusa-searchd"),
 						    NULL);
 	}
 	else {
 		/* There is currently no index available, so we need to explain
-		   whether a new index needs to be made, and if nautilus can direct it
-		   to be made correctly. 
-		   There are three possibilities here:
-		   1.  There is no index on this system,  and one is not currently being made.
-		   2.  There is no index on this system, but one is currently being made.
-		   3.  We can't contact the indexing service. */
-		index_service_availability = medusa_index_service_is_available ();
-		switch (index_service_availability) {
-		case MEDUSA_INDEXER_READY_TO_INDEX:
-			error_string = backup_search_is_available
-				? N_("To do a fast search, Find requires an index "
-				     "of the files on your system.  "
-				     "Your computer does not have an index "
-				     "right now.  Because Find cannot use an "
-				     "index, this search may take several "
-				     "minutes.  "
-				     "Would you like to create an index? "
-				     "Creating an index will be done while "
-				     "you are not actively using your computer.")
-				: N_("To do a content search, Find requires an index "
-				     "of the content on your system.  "
-				     "Your computer does not have an index "
-				     "right now.  Would you like to create an index?  "
-				     "Creating an index will be done while you are not "
-				     "actively using your computer.");
-			title_string = backup_search_is_available
-				? N_("Indexed searches are not available")
-				: N_("Content searches are not available");
-			index_problem_dialog = nautilus_yes_no_dialog (error_string,
-								       title_string,
-								       _("Create an Index"),
-								       _("Don't Create an Index Now"),
-								       NULL);
-			create_index_button = nautilus_gnome_dialog_get_button_by_index (index_problem_dialog,
-											  GNOME_OK);
-			gtk_signal_connect (GTK_OBJECT (create_index_button),
-					    "clicked",
-					    nautilus_indexing_info_request_reindex,
-					    NULL);
-			break;
-		case MEDUSA_INDEXER_ALREADY_INDEXING:
+		   whether a new index needs to be made, or whether one is currently
+		   being made. */
+ 		if (medusa_indexing_is_currently_in_progress ()) {
 			error_string = backup_search_is_available 
 				? N_("To do a fast search, Find requires an index "
-				    "of the files on your system.  "
+				     "of the files on your system.  "
 				    "Your computer is currently creating that "
 				     "index.   Because Find cannot use an index, "
 				     "this search may take several "
@@ -293,39 +281,55 @@ display_indexed_search_problems_dialog (gboolean backup_search_is_available)
 			title_string = backup_search_is_available
 				? N_("Indexed searches are not available")
 				: N_("Content searches are not available");
-			nautilus_error_dialog (error_string,
+			eel_show_error_dialog (error_string,
 					       title_string,
 					       NULL);
-			break;
-		default:
+		}
+		else {
 			error_string = backup_search_is_available
 				? N_("To do a fast search, Find requires an index "
-				     "of the files on your system.  "
-				     "An index can't be created "
-				     "right now. When an index is not "
-				     "available, searches will "
+				     "of the files on your system.  No index "
+				     "is available right now. You can create an "
+				     "index by running \"medusa-indexd\" as root "
+				     "on the command line.  Until a complete index "
+				     "is available, searches will "
 				     "take several minutes.")
 				: N_("To do a content search, Find requires an index "
-				     "of the content on your system.  "
-				     "An index can't be created "
-				     "right now.");
+				     "of the content on your system.  No index is "
+				     "available right now.  You can create an "
+				     "index by running \"medusa-indexd\" as root "
+				     "on the command line.  Until a complete index "
+				     "is available, content searches cannot be "
+				     "performed.");
 			title_string = backup_search_is_available
 				? N_("Indexed searches are not available")
 				: N_("Content searches are not available");
-			nautilus_error_dialog_with_details (error_string,
-							    title_string,
-							    _("The program that creates an index "
-							      "is not set up correctly.  You can "
-							      "create an index by hand by "
-							      "running \"medusa-indexd\" as root "
-							      "on the command line."),
-							    NULL);
-			break;
+			eel_show_error_dialog (error_string,
+					       title_string,
+					       NULL);
 		}
 	}
 
 }
 
+static void     
+display_system_services_are_disabled_dialog (gboolean unindexed_search_is_available)
+{
+	GnomeDialog *dialog_shown;
+	char *details_string;
+
+	details_string = nautilus_medusa_get_explanation_of_enabling ();
+	dialog_shown = eel_show_info_dialog_with_details (_("To do a fast search, Find requires an index of "
+							    "the files on your system. Your system administrator "
+							    "has disabled fast search on your computer, so no index "
+							    "is available."),
+							  _("Fast searches are not enabled on your computer"),
+							  details_string,
+							  NULL);
+	g_free (details_string);
+}
+
+
 #endif	
 
 static void
@@ -346,17 +350,18 @@ fm_search_list_view_initialize_class (gpointer klass)
 		real_get_emblem_names_to_exclude;
 	fm_directory_view_class->file_limit_reached = real_file_limit_reached;
   	fm_directory_view_class->merge_menus = real_merge_menus;
-	fm_directory_view_class->supports_creating_files = 
-		real_supports_creating_files;
+	fm_directory_view_class->is_read_only = real_is_read_only;
 	fm_directory_view_class->accepts_dragged_files = 
 		real_accepts_dragged_files;
 	fm_directory_view_class->supports_properties = 
 		real_supports_properties;
   	fm_directory_view_class->update_menus =	real_update_menus;
+  	fm_directory_view_class->load_error = real_load_error;
 
 	fm_list_view_class->adding_file = real_adding_file;
 	fm_list_view_class->removing_file = real_removing_file;
 	fm_list_view_class->get_number_of_columns = real_get_number_of_columns;
+	fm_list_view_class->get_emblems_column = real_get_emblems_column;
 	fm_list_view_class->get_link_column = real_get_link_column;
 	fm_list_view_class->get_column_specification = real_get_column_specification;
 	fm_list_view_class->get_default_sort_attribute = real_get_default_sort_attribute;
@@ -384,10 +389,6 @@ fm_search_list_view_initialize (gpointer object,
 			    "load_location",
 			    GTK_SIGNAL_FUNC (load_location_callback),
 			    NULL);
-	gtk_signal_connect (GTK_OBJECT (directory_view),
-			    "load_error",
-			    GTK_SIGNAL_FUNC (load_error_callback),
-			    NULL);
 }
 
 static void
@@ -403,7 +404,7 @@ real_destroy (GtkObject *object)
 	}
 	g_free (search_view->details);
 
-	NAUTILUS_CALL_PARENT_CLASS (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 static int
@@ -454,7 +455,7 @@ real_get_default_sort_attribute (FMListView *view)
 	return sort_attribute;
 }
 
-static NautilusStringList *
+static EelStringList *
 real_get_emblem_names_to_exclude (FMDirectoryView *view)
 {
 	g_assert (FM_IS_DIRECTORY_VIEW (view));
@@ -465,6 +466,12 @@ real_get_emblem_names_to_exclude (FMDirectoryView *view)
 
 static int
 real_get_link_column (FMListView *view)
+{
+	return 1;
+}
+
+static int
+real_get_emblems_column (FMListView *view)
 {
 	return 2;
 }
@@ -482,17 +489,17 @@ real_get_column_specification (FMListView *view,
 					 0, 0, 0, FALSE);
 		break;
 	case 1:
-		fm_list_view_column_set (specification,
-					 "emblems", NULL,
-					 NAUTILUS_FILE_SORT_BY_EMBLEMS,
-					 20, 20, 300, FALSE);
-		break;
-	case 2:
 		fm_list_view_column_set (specification,
 					 "name", _("Name"),
 					 NAUTILUS_FILE_SORT_BY_NAME,
 					 30, 150, 300, FALSE);
 		break;
+	case 2:
+		fm_list_view_column_set (specification,
+					 "emblems", _("Emblems"),
+					 NAUTILUS_FILE_SORT_BY_EMBLEMS,
+					 20, 52, 300, FALSE);
+		break;
 	case 3:
 		fm_list_view_column_set (specification,
 					 "where", _("Where"),
@@ -561,7 +568,7 @@ compute_reveal_item_name_and_sensitivity (GList *selected_files,
 	*return_sensitivity = selected_files != NULL;
 	
         if (return_name_no_underscore != NULL) {
-        	*return_name_no_underscore = nautilus_str_strip_chr (name_with_underscore, '_');
+        	*return_name_no_underscore = eel_str_strip_chr (name_with_underscore, '_');
         }
 
         if (return_name_with_underscore != NULL) {
@@ -595,7 +602,7 @@ real_add_file (FMDirectoryView *view, NautilusFile *file)
 		/* Tell the normal list-view code to add this file. It will add
 		 * and ref it only if it's not already in the list.
 		 */ 
-		NAUTILUS_CALL_PARENT_CLASS 
+		EEL_CALL_PARENT 
 			(FM_DIRECTORY_VIEW_CLASS, add_file, (view, real_file));
 	}
 
@@ -612,7 +619,7 @@ real_adding_file (FMListView *view, NautilusFile *file)
 	g_assert (FM_IS_SEARCH_LIST_VIEW (view));
 	g_assert (NAUTILUS_IS_FILE (file));
 
-	NAUTILUS_CALL_PARENT_CLASS (FM_LIST_VIEW_CLASS, adding_file, (view, file));
+	EEL_CALL_PARENT (FM_LIST_VIEW_CLASS, adding_file, (view, file));
 
 	/* FIXME bugzilla.eazel.com 5059: this implies that positioning, custom icon, icon
 	 * stretching, etc, will be based on the real directory the file is in,
@@ -646,7 +653,7 @@ real_removing_file (FMListView *view, NautilusFile *file)
 	nautilus_file_monitor_remove (file, view);
 	gtk_signal_disconnect_by_func 
 		(GTK_OBJECT (file), fm_directory_view_queue_file_change, view);
-	NAUTILUS_CALL_PARENT_CLASS (FM_LIST_VIEW_CLASS, removing_file, (view, file));
+	EEL_CALL_PARENT (FM_LIST_VIEW_CLASS, removing_file, (view, file));
 }
 
 static gboolean
@@ -667,10 +674,10 @@ real_file_limit_reached (FMDirectoryView *view)
 	 * to the way files are collected in batches. So you can't assume that
 	 * no more than the constant limit are displayed.
 	 */
-	nautilus_warning_dialog (_("Nautilus found more search results than it can display. "
-				   "Some matching items will not be displayed. "), 
-				 _("Too Many Matches"),
-				 fm_directory_view_get_containing_window (view));
+	eel_show_warning_dialog (_("Nautilus found more search results than it can display. "
+				        "Some matching items will not be displayed. "), 
+				      _("Too Many Matches"),
+				      fm_directory_view_get_containing_window (view));
 }
 
 static void
@@ -709,7 +716,7 @@ real_merge_menus (FMDirectoryView *view)
 		BONOBO_UI_VERB_END
 	};
 
-	NAUTILUS_CALL_PARENT_CLASS (FM_DIRECTORY_VIEW_CLASS, merge_menus, (view));
+	EEL_CALL_PARENT (FM_DIRECTORY_VIEW_CLASS, merge_menus, (view));
 
 	search_view = FM_SEARCH_LIST_VIEW (view);
 
@@ -724,12 +731,12 @@ real_merge_menus (FMDirectoryView *view)
 }
 
 static gboolean
-real_supports_creating_files (FMDirectoryView *view)
+real_is_read_only (FMDirectoryView *view)
 {
 	/* The user is not allowed to modify the contents of a search
 	 * results view.
 	 */
-	return FALSE;
+	return TRUE;
 }
 
 static gboolean
@@ -758,7 +765,7 @@ real_update_menus (FMDirectoryView *view)
 {
 	g_assert (FM_IS_SEARCH_LIST_VIEW (view));
 
-	NAUTILUS_CALL_PARENT_CLASS (FM_DIRECTORY_VIEW_CLASS, update_menus, (view));
+	EEL_CALL_PARENT (FM_DIRECTORY_VIEW_CLASS, update_menus, (view));
 
 	update_reveal_item (FM_SEARCH_LIST_VIEW (view));
 }
@@ -789,7 +796,7 @@ reveal_selected_items_callback (BonoboUIComponent *component, gpointer user_data
 					(fm_directory_view_get_nautilus_view (directory_view), 
 					 parent_uri,
 					 file_as_list);
-				nautilus_g_list_free_deep (file_as_list);
+				eel_g_list_free_deep (file_as_list);
 			}
 			g_free (parent_uri);
 		}
