@@ -415,85 +415,12 @@ migrate_old_nautilus_files (void)
 	g_free (old_desktop_dir);
 }
 
-/* We do this work here instead of in the Mozilla component, because
- * we want all these paths and such set before starting that
- * component. This imitates the logic in the galeon startup script.
- */
-
-static gboolean
-is_mozilla_path_good (const char *path)
-{
-	char *file_name;
-	gboolean good;
-
-	file_name = g_strconcat (path, "/chrome/embed.jar", NULL);
-	good = g_file_exists (file_name);
-	g_free (file_name);
-	return good;
-}
-
-static char *
-get_mozilla_path (void)
-{
-	const char *path;
-	guint i;
-	const char * const paths[] = {
-		"/usr/local/mozilla",
-		"/usr/lib/mozilla",
-		"/opt/mozilla",
-		"/usr/lib/mozilla-0.8.1" /* lame, but needed for Ximian package */
-	};
-
-	path = g_getenv ("MOZILLA_FIVE_HOME");
-	if (path != NULL) {
-		return g_strdup (path);
-	}
-
-	for (i = 0; i < EEL_N_ELEMENTS (paths); i++) {
-		if (is_mozilla_path_good (paths[i])) {
-			return g_strdup (paths[i]);
-		}
-	}
-
-	return NULL;
-}
-
-static void
-find_mozilla (void)
-{
-	char *mozilla_path;
-	const char *old_library_path;
-	char *new_library_path;
-
-	mozilla_path = get_mozilla_path ();
-	if (mozilla_path == NULL) {
-		g_warning ("Unable to find Mozilla with MOZILLA_FIVE_HOME or looking in standard places.");
-		return;
-	}
-
-	old_library_path = g_getenv ("LD_LIBRARY_PATH");
-	if (old_library_path == NULL) {
-		new_library_path = g_strdup (mozilla_path);
-	} else {
-		new_library_path = g_strconcat (mozilla_path, ":", old_library_path, NULL);
-	}
-	eel_setenv ("LD_LIBRARY_PATH", new_library_path, TRUE);
-	g_free (new_library_path);
-
-	eel_setenv ("MOZILLA_FIVE_HOME", mozilla_path, TRUE);
-
-	g_free (mozilla_path);
-}
-
 static void
 finish_startup (NautilusApplication *application)
 {
 	/* initialize the sound machinery */
 	nautilus_sound_initialize ();
 
-	/* find Mozilla */
-	find_mozilla ();
-	
 	/* Make the desktop work with gmc and old Nautilus. */
 	migrate_gmc_trash ();
 	migrate_old_nautilus_files ();
@@ -871,10 +798,7 @@ need_to_show_first_time_druid (void)
 	
 	user_directory = nautilus_get_user_directory ();
 
-	druid_flag_file_name = g_strdup_printf ("%s/%s",
-						user_directory,
-						"first-time-flag");
-
+	druid_flag_file_name = g_strconcat (user_directory, "/first-time-flag", NULL);
 	result = !g_file_exists (druid_flag_file_name);	
 	g_free (druid_flag_file_name);
 
@@ -882,10 +806,8 @@ need_to_show_first_time_druid (void)
 	 * check for and delete the old one, if the new one didn't exist 
 	 */
 	if (result) {
-		druid_flag_file_name = g_strdup_printf ("file://%s/%s",
-						user_directory,
-						"first-time-wizard-flag");
-		gnome_vfs_unlink (druid_flag_file_name);
+		druid_flag_file_name = g_strconcat (user_directory, "/first-time-wizard-flag", NULL);
+		unlink (druid_flag_file_name);
 		g_free (druid_flag_file_name);
 	}
 	g_free (user_directory); 
