@@ -38,9 +38,9 @@
 #include <libgnome/gnome-i18n.h>
 #include <libgnomeui/gnome-dock.h>
 #include <libgnomeui/gnome-uidefs.h>
-#include <libnautilus-extensions/nautilus-directory.h>
-#include <libnautilus-extensions/nautilus-global-preferences.h>
-#include <libnautilus-extensions/nautilus-gtk-macros.h>
+#include <libnautilus-private/nautilus-directory.h>
+#include <libnautilus-private/nautilus-global-preferences.h>
+#include <eel/eel-gtk-macros.h>
 
 static void		     real_activate				     (NautilusNavigationBar	       *bar);
 static void                  nautilus_switchable_search_bar_set_location     (NautilusNavigationBar            *bar,
@@ -55,7 +55,7 @@ static NautilusSearchBarMode nautilus_search_uri_to_search_bar_mode          (co
 static gboolean              nautilus_search_uri_is_displayable_by_mode      (const char *uri,
 									      NautilusSearchBarMode mode);
 
-NAUTILUS_DEFINE_CLASS_BOILERPLATE (NautilusSwitchableSearchBar,
+EEL_DEFINE_CLASS_BOILERPLATE (NautilusSwitchableSearchBar,
 				   nautilus_switchable_search_bar,
 				   NAUTILUS_TYPE_SEARCH_BAR)
 
@@ -103,11 +103,11 @@ nautilus_switchable_search_bar_destroy (GtkObject *object)
 
 	bar = NAUTILUS_SWITCHABLE_SEARCH_BAR (object);
 
-	nautilus_preferences_remove_callback (NAUTILUS_PREFERENCES_SEARCH_BAR_TYPE,
+	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_SEARCH_BAR_TYPE,
 					      search_bar_preference_changed_callback,
 					      bar);
 
-	NAUTILUS_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 GtkWidget *
@@ -156,13 +156,13 @@ nautilus_switchable_search_bar_new (NautilusWindow *window)
 	gtk_widget_show_all (hbox);
 	nautilus_switchable_search_bar_set_mode 
 		(bar, 
-		 nautilus_preferences_get_integer (NAUTILUS_PREFERENCES_SEARCH_BAR_TYPE));
-
+		 eel_preferences_get_integer (NAUTILUS_PREFERENCES_SEARCH_BAR_TYPE));
+	
 	/* React to future preference changes. */
-	nautilus_preferences_add_callback (NAUTILUS_PREFERENCES_SEARCH_BAR_TYPE,
-					   search_bar_preference_changed_callback,
-					   bar);
-
+	eel_preferences_add_callback (NAUTILUS_PREFERENCES_SEARCH_BAR_TYPE,
+				      search_bar_preference_changed_callback,
+				      bar);
+	
 	return switchable_search_bar;
 
 }
@@ -283,7 +283,7 @@ nautilus_search_uri_to_search_bar_mode (const char *uri)
 {
 	NautilusSearchBarMode preferred_mode;
 
-	preferred_mode = nautilus_preferences_get_integer (NAUTILUS_PREFERENCES_SEARCH_BAR_TYPE);
+	preferred_mode = eel_preferences_get_integer (NAUTILUS_PREFERENCES_SEARCH_BAR_TYPE);
 	if (nautilus_search_uri_is_displayable_by_mode (uri, preferred_mode)) {
 		return preferred_mode;
 	}
