@@ -37,22 +37,16 @@
 #include "nautilus-window.h"
 #include <bonobo/bonobo-zoomable-frame.h>
 #include <bonobo/bonobo-zoomable.h>
-#include <gtk/gtksignal.h>
 #include <gtk/gtkmain.h>
-#include <libnautilus-extensions/nautilus-bonobo-extensions.h>
-#include <libnautilus-extensions/nautilus-gtk-extensions.h>
-#include <libnautilus-extensions/nautilus-gtk-macros.h>
-#include <libnautilus-extensions/nautilus-undo-manager.h>
+#include <gtk/gtksignal.h>
+#include <libnautilus-private/nautilus-bonobo-extensions.h>
+#include <eel/eel-gtk-extensions.h>
+#include <eel/eel-gtk-macros.h>
+#include <libnautilus-private/nautilus-undo-manager.h>
+#include <libnautilus/nautilus-bonobo-workarounds.h>
 #include <libnautilus/nautilus-idle-queue.h>
 #include <libnautilus/nautilus-view.h>
 
-/* FIXME bugzilla.eazel.com 2456: Is a hard-coded 12 seconds wait to
- * detect that a view is gone acceptable? Can a component that is
- * working still take 12 seconds to respond?
- */
-/* Milliseconds */
-#define VIEW_RESPONSE_TIMEOUT 12000
-
 enum {
 	CHANGE_SELECTION,
 	CHANGE_STATUS,
@@ -66,6 +60,7 @@ enum {
 	OPEN_LOCATION_IN_THIS_WINDOW,
 	OPEN_LOCATION_PREFER_EXISTING_WINDOW,
 	REPORT_LOCATION_CHANGE,
+	REPORT_REDIRECT,
 	TITLE_CHANGED,
 	VIEW_LOADED,
 	ZOOM_LEVEL_CHANGED,
@@ -100,13 +95,12 @@ struct NautilusViewFrameDetails {
 	BonoboUIContainer *ui_container;
         NautilusUndoManager *undo_manager;
 
-	guint check_if_view_is_gone_timeout_id;
-
 	NautilusBonoboActivationHandle *activation_handle;
 
 	NautilusIdleQueue *idle_queue;
 
-	guint view_frame_failed_id;
+	guint failed_idle_id;
+	guint socket_gone_idle_id;
 };
 
 static void nautilus_view_frame_initialize       (NautilusViewFrame      *view);
@@ -118,9 +112,9 @@ static void send_history                         (NautilusViewFrame      *view);
 
 static guint signals[LAST_SIGNAL];
 
-NAUTILUS_DEFINE_CLASS_BOILERPLATE (NautilusViewFrame,
-				   nautilus_view_frame,
-				   NAUTILUS_TYPE_GENEROUS_BIN)
+EEL_DEFINE_CLASS_BOILERPLATE (NautilusViewFrame,
+			      nautilus_view_frame,
+			      EEL_TYPE_GENEROUS_BIN)
 
 void
 nautilus_view_frame_queue_incoming_call (PortableServer_Servant servant,
@@ -132,7 +126,9 @@ nautilus_view_frame_queue_incoming_call (PortableServer_Servant servant,
 
 	view = ((impl_POA_Nautilus_ViewFrame *) servant)->view;
 	if (view == NULL) {
-		(* destroy_callback_data) (callback_data);
+		if (destroy_callback_data != NULL) {
+			(* destroy_callback_data) (callback_data);
+		}
 		return;
 	}
 
@@ -187,7 +183,7 @@ nautilus_view_frame_initialize_class (NautilusViewFrameClass *klass)
 		 object_class->type,
 		 GTK_SIGNAL_OFFSET (NautilusViewFrameClass, 
 				    get_history_list),
-		 nautilus_gtk_marshal_POINTER__NONE,
+		 eel_gtk_marshal_POINTER__NONE,
 		 GTK_TYPE_POINTER, 0);
 	signals[GO_BACK] = gtk_signal_new
 		("go_back",
@@ -227,7 +223,7 @@ nautilus_view_frame_initialize_class (NautilusViewFrameClass *klass)
 		 object_class->type,
 		 GTK_SIGNAL_OFFSET (NautilusViewFrameClass, 
 				    open_location_force_new_window),
-		 nautilus_gtk_marshal_NONE__STRING_POINTER,
+		 eel_gtk_marshal_NONE__STRING_POINTER,
 		 GTK_TYPE_NONE, 2, GTK_TYPE_STRING, GTK_TYPE_POINTER);
 	signals[OPEN_LOCATION_IN_THIS_WINDOW] = gtk_signal_new
 		("open_location_in_this_window",
@@ -251,8 +247,16 @@ nautilus_view_frame_initialize_class (NautilusViewFrameClass *klass)
 		 object_class->type,
 		 GTK_SIGNAL_OFFSET (NautilusViewFrameClass, 
 				    report_location_change),
-		 nautilus_gtk_marshal_NONE__STRING_POINTER_STRING,
+		 eel_gtk_marshal_NONE__STRING_POINTER_STRING,
 		 GTK_TYPE_NONE, 3, GTK_TYPE_STRING, GTK_TYPE_POINTER, GTK_TYPE_STRING);
+	signals[REPORT_REDIRECT] = gtk_signal_new
+		("report_redirect",
+		 GTK_RUN_LAST,
+		 object_class->type,
+		 GTK_SIGNAL_OFFSET (NautilusViewFrameClass, 
+				    report_redirect),
+		 eel_gtk_marshal_NONE__STRING_STRING_POINTER_STRING,
+		 GTK_TYPE_NONE, 4, GTK_TYPE_STRING, GTK_TYPE_STRING, GTK_TYPE_POINTER, GTK_TYPE_STRING);
 	signals[TITLE_CHANGED] = gtk_signal_new
 		("title_changed",
 		 GTK_RUN_LAST,
@@ -318,16 +322,22 @@ stop_activation (NautilusViewFrame *view)
 static void
 destroy_view (NautilusViewFrame *view)
 {
-	if (view->details->view == NULL) {
+	CORBA_Environment ev;
+
+	if (view->details->view == CORBA_OBJECT_NIL) {
 		return;
 	}
 	
 	g_free (view->details->view_iid);
 	view->details->view_iid = NULL;
-	
-	bonobo_object_release_unref (view->details->view, NULL);
+
+	CORBA_exception_init (&ev);
+	CORBA_Object_release (view->details->view, &ev);
+	CORBA_exception_free (&ev);
 	view->details->view = CORBA_OBJECT_NIL;
 
+	nautilus_bonobo_object_call_when_remote_object_disappears
+		(view->details->view_frame, CORBA_OBJECT_NIL, NULL, NULL);
 	bonobo_object_unref (view->details->view_frame);
 	view->details->view_frame = NULL;
 	view->details->control_frame = NULL;
@@ -338,11 +348,6 @@ destroy_view (NautilusViewFrame *view)
 	}
 	bonobo_object_unref (BONOBO_OBJECT (view->details->ui_container));
 	view->details->ui_container = NULL;
-
-	if (view->details->check_if_view_is_gone_timeout_id != 0) {
-		g_source_remove (view->details->check_if_view_is_gone_timeout_id);
-		view->details->check_if_view_is_gone_timeout_id = 0;
-	}
 }
 
 static void
@@ -357,9 +362,13 @@ nautilus_view_frame_destroy (GtkObject *object)
 
 	nautilus_idle_queue_destroy (view->details->idle_queue);
 
-	if (view->details->view_frame_failed_id != 0) {
-		gtk_idle_remove (view->details->view_frame_failed_id);
-		view->details->view_frame_failed_id = 0;
+	if (view->details->failed_idle_id != 0) {
+		gtk_idle_remove (view->details->failed_idle_id);
+		view->details->failed_idle_id = 0;
+	}
+	if (view->details->socket_gone_idle_id != 0) {
+		gtk_idle_remove (view->details->socket_gone_idle_id);
+		view->details->socket_gone_idle_id = 0;
 	}
 
 	/* It's good to be in "failed" state while shutting down
@@ -368,7 +377,7 @@ nautilus_view_frame_destroy (GtkObject *object)
 	 */
 	view->details->state = VIEW_FRAME_FAILED;
 	
-	NAUTILUS_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 static void
@@ -385,7 +394,7 @@ nautilus_view_frame_finalize (GtkObject *object)
 	g_free (view->details->label);
 	g_free (view->details);
 	
-	NAUTILUS_CALL_PARENT (GTK_OBJECT_CLASS, finalize, (object));
+	EEL_CALL_PARENT (GTK_OBJECT_CLASS, finalize, (object));
 }
 
 static void
@@ -570,31 +579,6 @@ nautilus_view_frame_new (BonoboUIContainer *ui_container,
 	return view_frame;
 }
 
-static gboolean
-check_if_view_is_gone (gpointer callback_data)
-{
-	NautilusViewFrame *view;
-	CORBA_Environment ev;
-	gboolean view_is_gone;
-
-	view = NAUTILUS_VIEW_FRAME (callback_data);
-
-	CORBA_exception_init (&ev);
-	view_is_gone = CORBA_Object_non_existent (view->details->view, &ev);
-	if (ev._major != CORBA_NO_EXCEPTION) {
-		view_is_gone = TRUE;
-	}
-	CORBA_exception_free (&ev);
-	
-	if (!view_is_gone) {
-		return TRUE;
-	}
-
-	view->details->check_if_view_is_gone_timeout_id = 0;
-	view_frame_failed (view);
-	return FALSE;
-}
-
 static void
 emit_zoom_parameters_changed_callback (gpointer data,
 				       gpointer callback_data)
@@ -690,16 +674,13 @@ create_corba_objects (NautilusViewFrame *view)
 
 
 static gboolean
-view_frame_failed_callback (gpointer data)
+view_frame_failed_callback (gpointer callback_data)
 {
-	NautilusViewFrame *view = data;
-
-	g_assert (NAUTILUS_IS_VIEW_FRAME (view));
-
-	view->details->view_frame_failed_id = 0;
+	NautilusViewFrame *view;
 
+	view = NAUTILUS_VIEW_FRAME (callback_data);
+	view->details->failed_idle_id = 0;
 	view_frame_failed (view);
-
 	return FALSE;
 }
 
@@ -708,15 +689,78 @@ queue_view_frame_failed (NautilusViewFrame *view)
 {
 	g_assert (NAUTILUS_IS_VIEW_FRAME (view));
 
-	if (view->details->view_frame_failed_id == 0)
-		view->details->view_frame_failed_id =
+	if (view->details->failed_idle_id == 0)
+		view->details->failed_idle_id =
 			gtk_idle_add (view_frame_failed_callback, view);
 }
 
 static void
-attach_view (NautilusViewFrame *view,
-	       BonoboObjectClient *client)
+view_frame_failed_cover (BonoboObject *object,
+			 gpointer callback_data)
 {
+	view_frame_failed (NAUTILUS_VIEW_FRAME (callback_data));
+}
+
+static gboolean
+check_socket_gone_idle_callback (gpointer callback_data)
+{
+	NautilusViewFrame *frame;
+	GtkWidget *widget;
+	GList *children;
+
+	frame = NAUTILUS_VIEW_FRAME (callback_data);
+	
+	frame->details->socket_gone_idle_id = 0;
+
+	widget = bonobo_control_frame_get_widget (frame->details->control_frame);
+
+	/* This relies on details of the BonoboControlFrame
+	 * implementation, specifically that's there's one level of
+	 * hierarchy between the widget returned by get_widget and the
+	 * actual plug.
+	 */
+	children = gtk_container_children (GTK_CONTAINER (widget));
+	g_list_free (children);
+
+	/* If there's nothing inside the widget at all, that means
+	 * that the socket went away because the remote plug went away.
+	 */
+	if (children == NULL) {
+		view_frame_failed (frame);
+	}
+
+	return FALSE;
+}
+
+static void
+check_socket_gone_callback (GtkContainer *container,
+			    GtkWidget *widget,
+			    gpointer callback_data)
+{
+	NautilusViewFrame *frame;
+
+	frame = NAUTILUS_VIEW_FRAME (callback_data);
+
+	/* There are two times the socket will be destroyed in Bonobo.
+	 * One is when a local control decides to not use the socket.
+	 * The other is when the remote plug goes away. The way to
+	 * tell these apart is to wait until idle time. At idle time,
+	 * if there's nothing in the container, then that means the
+	 * real socket went away. If it was just the local control
+	 * deciding not to use the socket, there will be another
+	 * widget in there.
+	 */
+	if (frame->details->socket_gone_idle_id == 0) {
+		frame->details->socket_gone_idle_id = gtk_idle_add
+			(check_socket_gone_idle_callback, callback_data);
+	}
+}
+
+static void
+attach_view (NautilusViewFrame *view,
+	     BonoboObjectClient *client)
+{
+	CORBA_Environment ev;
 	GtkWidget *widget;
   	
 	/* Either create an adapter or query for the Nautilus:View
@@ -734,6 +778,12 @@ attach_view (NautilusViewFrame *view,
 
 	create_corba_objects (view);
 
+	CORBA_exception_init (&ev);
+	Bonobo_Unknown_unref (view->details->view, &ev);
+	CORBA_exception_free (&ev);
+
+	widget = bonobo_control_frame_get_widget (view->details->control_frame);
+
 	gtk_signal_connect_object_while_alive
 		(GTK_OBJECT (view->details->view_frame),
 		 "destroy",
@@ -748,6 +798,12 @@ attach_view (NautilusViewFrame *view,
 		 "system_exception",
 		 queue_view_frame_failed, GTK_OBJECT (view));
 
+	gtk_signal_connect_while_alive
+		(GTK_OBJECT (widget),
+		 "remove",
+		 check_socket_gone_callback, view,
+		 GTK_OBJECT (view));
+
 	if (view->details->zoomable_frame != NULL) {
 		gtk_signal_connect_object_while_alive
 			(GTK_OBJECT (view->details->zoomable_frame),
@@ -766,15 +822,16 @@ attach_view (NautilusViewFrame *view,
 			 GTK_OBJECT (view));
 	}
 
-	widget = bonobo_control_frame_get_widget (view->details->control_frame);
 	gtk_widget_show (widget);
 	gtk_container_add (GTK_CONTAINER (view), widget);
 	
 	view_frame_activated (view);
 
-	g_assert (view->details->check_if_view_is_gone_timeout_id == 0);
-	view->details->check_if_view_is_gone_timeout_id
-		= g_timeout_add (VIEW_RESPONSE_TIMEOUT, check_if_view_is_gone, view);
+	nautilus_bonobo_object_call_when_remote_object_disappears
+		(view->details->view_frame,
+		 view->details->view,
+		 view_frame_failed_cover,
+		 view);
 }
 
 static void
@@ -860,7 +917,7 @@ nautilus_view_frame_stop (NautilusViewFrame *view)
 	
 	stop_activation (view);
 
-	if (view->details->state != VIEW_FRAME_EMPTY) {
+	if (view->details->view != CORBA_OBJECT_NIL) {
 		CORBA_exception_init (&ev);
 		Nautilus_View_stop_loading (view->details->view, &ev);
 		if (ev._major != CORBA_NO_EXCEPTION) {
@@ -879,15 +936,8 @@ nautilus_view_frame_selection_changed (NautilusViewFrame *view,
 	
 	g_return_if_fail (NAUTILUS_IS_VIEW_FRAME (view));
 	
-	switch (view->details->state) {
-	case VIEW_FRAME_EMPTY:
-	case VIEW_FRAME_FAILED:
+	if (view->details->view == CORBA_OBJECT_NIL) {
 		return;
-	case VIEW_FRAME_NO_LOCATION:
-	case VIEW_FRAME_UNDERWAY:
-	case VIEW_FRAME_LOADED:
-	case VIEW_FRAME_WAITING:
-		break;
 	}
 
 	uri_list = nautilus_uri_list_from_g_list (selection);
@@ -910,15 +960,8 @@ nautilus_view_frame_title_changed (NautilusViewFrame *view,
 	
 	g_return_if_fail (NAUTILUS_IS_VIEW_FRAME (view));
 	
-	switch (view->details->state) {
-	case VIEW_FRAME_EMPTY:
-	case VIEW_FRAME_FAILED:
+	if (view->details->view == CORBA_OBJECT_NIL) {
 		return;
-	case VIEW_FRAME_NO_LOCATION:
-	case VIEW_FRAME_UNDERWAY:
-	case VIEW_FRAME_LOADED:
-	case VIEW_FRAME_WAITING:
-		break;
 	}
 
 	CORBA_exception_init (&ev);
@@ -1146,6 +1189,28 @@ nautilus_view_frame_report_location_change (NautilusViewFrame *view,
 			 location, selection, title);
 }
 
+void
+nautilus_view_frame_report_redirect (NautilusViewFrame *view,
+				     const char *from_location,
+				     const char *to_location,
+				     GList *selection,
+				     const char *title)
+{
+	g_return_if_fail (NAUTILUS_IS_VIEW_FRAME (view));
+
+	if (view->details->state == VIEW_FRAME_FAILED) {
+		return;
+	}
+
+	g_free (view->details->title);
+	view->details->title = g_strdup (title);
+
+	view_frame_wait_is_over (view);
+	gtk_signal_emit (GTK_OBJECT (view),
+			 signals[REPORT_REDIRECT],
+			 from_location, to_location, selection, title);
+}
+
 void
 nautilus_view_frame_report_selection_change (NautilusViewFrame *view,
                                              GList *selection)
@@ -1215,6 +1280,16 @@ nautilus_view_frame_report_load_failed (NautilusViewFrame *view)
 	view_frame_failed (view);
 }
 
+/* return the Bonobo_Control CORBA object associated with the view frame */
+Bonobo_Control
+nautilus_view_frame_get_control (NautilusViewFrame *view)
+{
+	if (view->details->control_frame == NULL) {
+		return CORBA_OBJECT_NIL;
+	}
+	return bonobo_control_frame_get_control (view->details->control_frame);
+}
+
 void
 nautilus_view_frame_go_back (NautilusViewFrame *view)
 {
@@ -1278,8 +1353,7 @@ nautilus_view_frame_set_label (NautilusViewFrame *view,
 /* Activate the underlying control frame whenever the view is mapped.
  * This causes the view to merge its menu items, for example. For
  * sidebar panels, it might be a little late to merge them at map
- * time, especially since we don't unmerge them at unmap time (not
- * until destroy time).
+ * time. What's a better time?
  */
 static void
 nautilus_view_frame_map (GtkWidget *view_as_widget)
@@ -1288,7 +1362,7 @@ nautilus_view_frame_map (GtkWidget *view_as_widget)
 
 	view = NAUTILUS_VIEW_FRAME (view_as_widget);
 
-	NAUTILUS_CALL_PARENT (GTK_WIDGET_CLASS, map, (view_as_widget));
+	EEL_CALL_PARENT (GTK_WIDGET_CLASS, map, (view_as_widget));
 
 	if (view->details->control_frame != NULL) {
 		bonobo_control_frame_control_activate (view->details->control_frame);
@@ -1315,15 +1389,8 @@ send_history (NautilusViewFrame *view)
 
 	g_return_if_fail (NAUTILUS_IS_VIEW_FRAME (view));
 	
-	switch (view->details->state) {
-	case VIEW_FRAME_EMPTY:
-	case VIEW_FRAME_FAILED:
+	if (view->details->view == CORBA_OBJECT_NIL) {
 		return;
-	case VIEW_FRAME_NO_LOCATION:
-	case VIEW_FRAME_WAITING:
-	case VIEW_FRAME_UNDERWAY:
-	case VIEW_FRAME_LOADED:
-		break;
 	}
 
 	history = get_history_list (view);
