@@ -30,9 +30,9 @@
 #define NAUTILUS_WINDOW_H
 
 #include <bonobo/bonobo-win.h>
-#include <libnautilus-extensions/nautilus-glib-extensions.h>
-#include <libnautilus-extensions/nautilus-bookmark.h>
-#include <libnautilus-extensions/nautilus-view-identifier.h>
+#include <eel/eel-glib-extensions.h>
+#include <libnautilus-private/nautilus-bookmark.h>
+#include <libnautilus-private/nautilus-view-identifier.h>
 #include "nautilus-applicable-views.h"
 #include "nautilus-view-frame.h"
 #include "nautilus-sidebar.h"
@@ -94,7 +94,6 @@ struct NautilusWindow {
         
         /* Current views stuff */
         NautilusViewFrame *content_view;
-        NautilusViewIdentifier *content_view_id;
         GList *sidebar_panels;
         
         /* Widgets to keep track of (for state changes, etc) */      
